package com.ruoyi.common.pay.xy.service;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.pay.PayApi;
import com.ruoyi.common.pay.Payable;
import com.ruoyi.common.pay.Refundable;
import com.ruoyi.common.pay.xy.config.XyPayConfig;
import com.ruoyi.common.pay.xy.constants.XyPayConstants;
import com.ruoyi.common.pay.xy.utils.HttpUtil;
import com.ruoyi.common.pay.xy.utils.XyPayUtil;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.wechat.pay.java.service.payments.jsapi.model.PrepayWithRequestPaymentResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Objects;
import java.util.TreeMap;

/**
 * @author wjh
 * 2025/1/8
 */
@Service
@Slf4j
public class XyWxPayService implements PayApi {
    @Override
    public Object pay(Payable payable, Object config) {
        XyPayConfig payConfig = (XyPayConfig) config;

        // 请求地址
        String url = payConfig.getHost() + "/yyfsevr/order/pay";

        // 请求参数
        TreeMap<String, Object> params = new TreeMap<>();
        params.put("agetId", payConfig.getAgetId());
        params.put("custId", payConfig.getCustId());
        params.put("orderNo", payable.payableOutTradeNo());
        params.put("txamt", payable.payableFen());
        params.put("openid", payable.payableOpenId());
        params.put("payWay", XyPayConstants.PAY_WAY_WX);
        params.put("ip", payable.payableIp());
        params.put("timeStamp", DateUtils.format(LocalDateTime.now(), "yyyyMMddHHmmss"));
        params.put("version", "1.0.0");

        // 参数签名
        params.put("sign", XyPayUtil.encrypt(params, payConfig.getPublicKey()));

        // 发送请求
        try {
            String response = HttpUtil.postData(url, params);
            ServiceUtil.assertion(response == null, "响应结果为空");
            JSONObject json = JSONObject.parseObject(response);
            String code = json.getString("code");
            if (Objects.equals("000000", code)) {
                JSONObject data = json.getJSONObject("data");
                ServiceUtil.assertion(data == null, "响应数据为空");
                PrepayWithRequestPaymentResponse result = new PrepayWithRequestPaymentResponse();
                result.setAppId(data.getString("jsapiAppid"));
                result.setTimeStamp(data.getString("jsapiTimestamp"));
                result.setNonceStr(data.getString("jsapiNoncestr"));
                result.setPackageVal(data.getString("jsapiPackage"));
                result.setSignType(data.getString("jsapiSignType"));
                result.setPaySign(data.getString("jsapiPaySign"));
                return result;
            }
        } catch (Exception e)  {
            log.error("支付请求失败：" + e.getMessage());
            return null;
        }

        return null;
    }

    @Override
    public void closeByOutTradeNo(String outTradeNo, Object config) {

    }

    @Override
    public Object queryByOutTradeNo(String outTradeNo, Object config) {
        return null;
    }

    @Override
    public Object refund(Refundable refundAble, Object config) {
        return null;
    }

    @Override
    public boolean isPaySuccessByOutTradeNo(String outTradeNo, Object config) {
        return false;
    }

    @Override
    public boolean isPaySuccess(Object result) {
        return false;
    }

    @Override
    public LocalDateTime getPayTime(Object result) {
        return null;
    }
}
